<!DOCTYPE TS><TS>
<defaultcodec></defaultcodec>
<context>
    <name></name>
    <message>
        <source>Error in config.py:</source>
        <translation>Erreur dans config.py :</translation>
    </message>
    <message>
        <source>Error when running plugin:</source>
        <translation>Erreur à l&apos;exécution du plugin :</translation>
    </message>
    <message>
        <source>Unable to load file.</source>
        <translation>impossible de charger le fichier.</translation>
    </message>
    <message>
        <source>Invalid file format.</source>
        <translation>Format de fichier invalide.</translation>
    </message>
    <message>
        <source>Unable to save file.</source>
        <translation>Impossible d&apos;enregistrer le fichier.</translation>
    </message>
    <message>
        <source>Unable to parse XML:</source>
        <translation>impossible d&apos;analyser le fichier XML :</translation>
    </message>
    <message>
        <source>Unrecognised encoding.</source>
        <translation>Encodage non-reconnu.</translation>
    </message>
    <message>
        <source>Missing answer on line:</source>
        <translation>Réponse absente à la ligne :</translation>
    </message>
    <message>
        <source>Unable to load database.
Creating tmp file.</source>
        <translation>impossible de charger la base de donnée.
Création d&apos;un fichier tmp.</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>File exists:</source>
        <translation>Le fichier existe :</translation>
    </message>
    <message>
        <source>&amp;Overwrite</source>
        <translation>&amp;Écraser</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Removed duplicates: </source>
        <translation>Cartes à double retirés : </translation>
    </message>
    <message>
        <source>There are cards with different answers for question:

</source>
        <translation>Il y a des cartes avec des réponses différentes pour la question :

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Fusionner et éditer</translation>
    </message>
    <message>
        <source>&amp;Don&apos;t merge</source>
        <translation>&amp;Ne pas fusionner</translation>
    </message>
    <message>
        <source>Done!</source>
        <translation>Fini!</translation>
    </message>
    <message>
        <source>You don&apos;t remember this card yet.</source>
        <translation>Vous ne vous souvenez pas encore de cette carte.</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but it&apos;s getting more familiar.</source>
        <translation>Comme &apos;0&apos;, mais ça devient plus familier.</translation>
    </message>
    <message>
        <source> Show it less often.</source>
        <translation> Le montrer moins souvent.</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this card now,</source>
        <translation>Maintenant, vous avez mémorisé cette carte</translation>
    </message>
    <message>
        <source> and will probably remember it for a few days.</source>
        <translation> et vous en souviendrez pendant quelques jours.</translation>
    </message>
    <message>
        <source>You have forgotten this card completely.</source>
        <translation>Vous avez complétement oublié cette carte.</translation>
    </message>
    <message>
        <source>Barely correct answer. The interval was way too long.</source>
        <translation>Réponse à peine correcte. L&apos;intervalle était beaucoup trop longue.</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort.</source>
        <translation>Réponse correcte, mais avec beaucoup d&apos;effort.</translation>
    </message>
    <message>
        <source> The interval was probably too long.</source>
        <translation>  L&apos;intervalle était probablement trop longue.</translation>
    </message>
    <message>
        <source>Correct answer, with some effort.</source>
        <translation>Réponse correcte, avec un peu d&apos;effort.</translation>
    </message>
    <message>
        <source> The interval was probably just right.</source>
        <translation> L&apos;intervalle était probablement adéquat.</translation>
    </message>
    <message>
        <source>Correct answer, but without any</source>
        <translation>Réponse correcte, mais sans</translation>
    </message>
    <message>
        <source> difficulties. The interval was probably too short.</source>
        <translation> difficultés.  L&apos;intervalle était probablement trop courte.</translation>
    </message>
</context>
<context>
    <name>AboutDlg</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Main author: Peter Bienstman

</source>
        <translation>Auteur principal : Peter Bienstman

</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.sourceforge.net
</source>
        <translation type="obsolete">Plus d&apos;information : http://mnemosyne-proj.sourceforge.net
</translation>
    </message>
    <message>
        <source>More info: http://mnemosyne-proj.org
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AboutFrm</name>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
</context>
<context>
    <name>ActivateCategoriesFrm</name>
    <message>
        <source>Activate categories</source>
        <translation>Activer les catégories</translation>
    </message>
    <message>
        <source>Select the categories to activate:</source>
        <translation>Sélectionner les catégories  pour les activer :</translation>
    </message>
    <message>
        <source>Activate none</source>
        <translation>Ne rien activer</translation>
    </message>
    <message>
        <source>Activate all</source>
        <translation>Tout activer</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>AddItemsDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;default&gt;</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Abandon current card?</source>
        <translation>Abandonner la carte en cours?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Oui</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Non</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Question :</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Réponse :</translation>
    </message>
    <message>
        <source>Written form:</source>
        <translation>Forme écrite :</translation>
    </message>
    <message>
        <source>Translation:</source>
        <translation>Traduction :</translation>
    </message>
    <message>
        <source>Card is already in database.
</source>
        <translation>Carte déjà dans la base de donnée.
</translation>
    </message>
    <message>
        <source>Duplicate not added.</source>
        <translation>Le double n&apos;a pas été ajouté.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>There are different answers for</source>
        <translation>Il y a des réponses différentes pour </translation>
    </message>
    <message>
        <source> this question:

</source>
        <translation> cette question :

</translation>
    </message>
    <message>
        <source>&amp;Merge and edit</source>
        <translation>&amp;Fusionner et éditer</translation>
    </message>
    <message>
        <source>&amp;Add as is</source>
        <translation>&amp;Ajouter tel quel</translation>
    </message>
    <message>
        <source>&amp;Do not add</source>
        <translation>&amp;Ne pas ajouter</translation>
    </message>
</context>
<context>
    <name>AddItemsFrm</name>
    <message>
        <source>Add cards</source>
        <translation>Ajouter des cartes</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Catégorie :</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Question :</translation>
    </message>
    <message>
        <source>Pronunciation:</source>
        <translation>Prononciation :</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Réponse :</translation>
    </message>
    <message>
        <source>Add &amp;vice versa too</source>
        <translation>Aussi ajouter une carte &amp;vice-versa</translation>
    </message>
    <message>
        <source>Alt+V</source>
        <translation>Alt+V</translation>
    </message>
    <message>
        <source>Select initial grade:</source>
        <translation>sélectionner la note initiale :</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>You don&apos;t remember this item yet or forgot it.</source>
        <translation>Vouns ne vous en souvenez pas encore ou bien vous l&apos;avez oublié.</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <source>Like &apos;0&apos;, but the item is getting more familiar.</source>
        <translation>Comme &apos;0&apos;, mais ça devient plus familier.</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <source>You&apos;ve memorised this item now, and will probably remember it for a few days.</source>
        <translation>Vous avez maintenant mémorisé ceci et vous en souviendrez pendant quelques jours.</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <source>Correct answer, but with much effort. The interval was probably too long</source>
        <translation>Réponse correcte,  mais avec beaucoup d&apos;effort. L&apos;intervalle était probablement trop grand</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <source>Correct answer, with some effort. The interval was probably just right.</source>
        <translation>Réponse correcte, avec un peu d&apos;effort. L&apos;intervalle était probablement adéquat.</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <source>Correct answer, but without any difficulties. The interval was probably too short.</source>
        <translation>Réponse correcte, mais sans difficultés.  L&apos;intervalle était probablement trop courte.</translation>
    </message>
    <message>
        <source>Type question and answer, then pick initial grade.</source>
        <translation>Ecrivez la question et la réponse, puis choisissez la note initiale.</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="obsolete">A&amp;perçu</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChangeCategoryFrm</name>
    <message>
        <source>Change category</source>
        <translation>Changer la catégorie</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Catégorie :</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>ConfigurationFrm</name>
    <message>
        <source>Mnemosyne configuration</source>
        <translation>Configuration de Mnemosyne</translation>
    </message>
    <message>
        <source>Hover with the mouse over the buttons to get extra information.</source>
        <translation>Survolez les boutons avec la souris pour plus d&apos;informations.</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <source>Set Q/A font</source>
        <translation>Choisir la police des question et réponses</translation>
    </message>
    <message>
        <source>Set the font used when showing single questions and answers</source>
        <translation>Choisir la police utilisée lors de l&apos;affichage individuelle de questions et réponses</translation>
    </message>
    <message>
        <source>Set list font</source>
        <translation>Choisir la police de la liste</translation>
    </message>
    <message>
        <source>Set the font used when showing the list of all the cards in the deck</source>
        <translation>Choisir la police utilisée lors de l&apos;affichage de la liste de toutes les cartes dans le jeu</translation>
    </message>
    <message>
        <source>Increase size of non-latin characters by</source>
        <translation>Agrandir les caractères non-latin de</translation>
    </message>
    <message>
        <source>Sometimes complex glyphs are hard to read at the default latin font size</source>
        <translation>Les glyphes comples peuvent parfois être dures à lire à la taille de police par défaut</translation>
    </message>
    <message>
        <source>point(s)</source>
        <translation>point(s)</translation>
    </message>
    <message>
        <source>Log uploading</source>
        <translation>Téléversement du journal de bord</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Téléverser anonymement le journal de bord</translation>
    </message>
    <message>
        <source>Share anonymous statistics to contribute to memory research</source>
        <translation>Partagez anonymement les statistiques pour contribuer à la recherche sur la mémoire</translation>
    </message>
    <message>
        <source>Duplicate handling</source>
        <translation>Traitement des cartes à doubles</translation>
    </message>
    <message>
        <source>Check for duplicates when adding new cards</source>
        <translation>Vérifier la présence de doublons lors de l&apos;ajout de nouvelles cartes</translation>
    </message>
    <message>
        <source>Allow duplicates in different categories</source>
        <translation>Authoriser des doubles dans différentes catégories</translation>
    </message>
    <message>
        <source>Repetition process</source>
        <translation>Processus de répétitions</translation>
    </message>
    <message>
        <source>Number of grade 0 cards to learn at once:</source>
        <translation type="obsolete">Nombres de cartes de note 0 à apprendre à la fois :</translation>
    </message>
    <message>
        <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
        <translation>Remarque : il ne s&apos;agit PAS du nombre de cartes notées 0 que vous voulez mémoriser *par jour*</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Defaults</source>
        <translation>Configuration par défaut</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Learn new cards in random order</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Number of grade 0 cards to hold in your hand:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditItemFrm</name>
    <message>
        <source>Edit card</source>
        <translation>Éditer la carte</translation>
    </message>
    <message>
        <source>Category:</source>
        <translation>Catégorie :</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Question :</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Réponse :</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>A&amp;perçu</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
<context>
    <name>EditItemsDlg</name>
    <message>
        <source>Please wait...</source>
        <translation>Veuillez patienter...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Edition</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>A&amp;perçu</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Add vice versa</source>
        <translation>&amp;Ajouter une carte vice-versa</translation>
    </message>
    <message>
        <source>S&amp;tatistics</source>
        <translation>S&amp;tatistiques</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Supprimer</translation>
    </message>
    <message>
        <source>&amp;Change category</source>
        <translation>&amp;Changer la catégorie</translation>
    </message>
    <message>
        <source>Add &amp;vice versa</source>
        <translation>&amp;Ajouter une carte vice-versa</translation>
    </message>
    <message>
        <source>Add vice versa of these cards?</source>
        <translation>Ajouter les vice-versas de ces cartes?</translation>
    </message>
    <message>
        <source>Add vice versa of this card?</source>
        <translation>Ajouter le vice-versa de cette carte?</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>

This could create duplicates if the vice </source>
        <translation>

Ceci pourrait créér un double si des cartes vice-</translation>
    </message>
    <message>
        <source>versas are already present, 
so you might want to run </source>
        <translation>versas sont déjà présentes, 
 il pourrait donc être souhaitaible de lancer </translation>
    </message>
    <message>
        <source>clean duplicates&apos; afterwards.</source>
        <translation>gérer les doubles&quot; par la suite.</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Oui</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Non</translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation>Note :</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation>Facilité :</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation>Répétitions :</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation>Oubils :</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation>Jours depuis la dernière répétition :</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation>Jours jusqu&apos;à la prochaine répétition :</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Delete these cards?</source>
        <translation>Supprimer ces cartes?</translation>
    </message>
    <message>
        <source>Delete this card?</source>
        <translation>Supprimer cette carte?</translation>
    </message>
    <message>
        <source>The text you entered was not found.</source>
        <translation>Le texte que vous entré n&apos;a pas été trouvé.</translation>
    </message>
    <message>
        <source>&amp;Find again</source>
        <translation>Re&amp;chercher à nouveau</translation>
    </message>
    <message>
        <source>F</source>
        <translation>F</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Re&amp;chercher</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="obsolete"></translation>
    </message>
</context>
<context>
    <name>EditItemsFrm</name>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Answer</source>
        <translation>Réponse</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Catégorie</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Éditer le jeu de cartes</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>Re&amp;chercher</translation>
    </message>
    <message>
        <source>To edit a card, right-click on it.</source>
        <translation>Pour éditer une carte, faite un clic droit dessus.</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Alt+X</source>
        <translation>Alt+X</translation>
    </message>
    <message>
        <source>Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExportDlg</name>
    <message>
        <source>All Files (*);;</source>
        <translation>Tous les fichiers (*);;</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
</context>
<context>
    <name>ExportFrm</name>
    <message>
        <source>Export to file</source>
        <translation>Exporter vers le fichier</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Format du fichier :</translation>
    </message>
    <message>
        <source>File to export to:</source>
        <translation>Fichier de destination :</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Parcourir</translation>
    </message>
    <message>
        <source>Categories to export:</source>
        <translation>Catégories à exporter :</translation>
    </message>
    <message>
        <source>&amp;Select all</source>
        <translation>&amp;Tout sélectionner</translation>
    </message>
    <message>
        <source>Reset learning data on export</source>
        <translation>Ré-initialiser les données d&apos;apprentissage lors de l&apos;export</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>ImportDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;default&gt;</translation>
    </message>
    <message>
        <source>All Files (*);;</source>
        <translation>Tous les fichiers (*);;</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importer</translation>
    </message>
</context>
<context>
    <name>ImportFrm</name>
    <message>
        <source>Import from file</source>
        <translation>Importer depuis</translation>
    </message>
    <message>
        <source>File format:</source>
        <translation>Format du fichier :</translation>
    </message>
    <message>
        <source>File to import from:</source>
        <translation>Fichier à partir duquel importer :</translation>
    </message>
    <message>
        <source>&amp;Browse</source>
        <translation>&amp;Parcourir</translation>
    </message>
    <message>
        <source>Put cards without category into this category:</source>
        <translation>Ranger les cartes sans catégorie dans cette catégorie :</translation>
    </message>
    <message>
        <source>Note: all cards will be added to the current database.</source>
        <translation>Remarque : les cartes seront ajoutés à la base de données actuelle.</translation>
    </message>
    <message>
        <source>Reset learning data on import</source>
        <translation>Réinitialisier les donnés lors de l&apos;import</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Annuler</translation>
    </message>
</context>
<context>
    <name>MainDlg</name>
    <message>
        <source>Mnemosyne databases (*.mem)</source>
        <translation>Bases de données Mnemosyne (*.mem)</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>Please wait...</source>
        <translation>Veuillez patienter...</translation>
    </message>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Delete current card?</source>
        <translation>Supprimer la carte actuelle?</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Oui</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Non</translation>
    </message>
    <message>
        <source>Returns in </source>
        <translation>Revient dans </translation>
    </message>
    <message>
        <source> day(s).</source>
        <translation> jour(s).</translation>
    </message>
    <message>
        <source>Next repetition: today.</source>
        <translation>Prochaine répétition : aujourd&apos;hui.</translation>
    </message>
    <message>
        <source>Next repetition: tomorrow.</source>
        <translation>Prochaine répétition : demain.</translation>
    </message>
    <message>
        <source>Next repetition in </source>
        <translation>Prochaine répétition dans </translation>
    </message>
    <message>
        <source> days.</source>
        <translation> jours.</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Question :</translation>
    </message>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;default&gt;</translation>
    </message>
    <message>
        <source>Show &amp;answer</source>
        <translation type="obsolete">Afficher la &amp;réponse</translation>
    </message>
    <message>
        <source>Learn ahead of schedule</source>
        <translation>Apprendre en avance</translation>
    </message>
    <message>
        <source>Pick days until next repetition:</source>
        <translation>Choisisser le nombre de jours jusqu&apos;à la prochaine répétition :</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Noter votre réponse :</translation>
    </message>
    <message>
        <source>Scheduled: </source>
        <translation>Cartes planifiés : </translation>
    </message>
    <message>
        <source>Not memorised: </source>
        <translation>Non-mémorisés : </translation>
    </message>
    <message>
        <source>All: </source>
        <translation>Total : </translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation type="unfinished">Afficher la réponse</translation>
    </message>
</context>
<context>
    <name>MainFrm</name>
    <message>
        <source>Mnemosyne</source>
        <translation>Mnemosyne</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Question :</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Réponse :</translation>
    </message>
    <message>
        <source>Show answer</source>
        <translation>Afficher la réponse</translation>
    </message>
    <message>
        <source>Grade your answer:</source>
        <translation>Noter votre réponse :</translation>
    </message>
    <message>
        <source>&amp;0</source>
        <translation>&amp;0</translation>
    </message>
    <message>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <source>&amp;1</source>
        <translation>&amp;1</translation>
    </message>
    <message>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <source>&amp;2</source>
        <translation>&amp;2</translation>
    </message>
    <message>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <source>&amp;3</source>
        <translation>&amp;3</translation>
    </message>
    <message>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <source>&amp;4</source>
        <translation>&amp;4</translation>
    </message>
    <message>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <source>&amp;5</source>
        <translation>&amp;5</translation>
    </message>
    <message>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <source>.</source>
        <translation>.</translation>
    </message>
    <message>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Ouvrir...</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Enregistrer</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Enregistrer &amp;sous...</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>À &amp;propos de Mnemosyne</translation>
    </message>
    <message>
        <source>Add cards</source>
        <translation>Ajouter des cartes</translation>
    </message>
    <message>
        <source>&amp;Add cards</source>
        <translation>&amp;Ajouter des cartes</translation>
    </message>
    <message>
        <source>Ctrl+A</source>
        <translation>Ctrl+A</translation>
    </message>
    <message>
        <source>Activate cate&amp;gories</source>
        <translation>Activer les caté&amp;gories</translation>
    </message>
    <message>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <source>Edit deck</source>
        <translation>Éditer le jeu de cartes</translation>
    </message>
    <message>
        <source>Edit &amp;deck</source>
        <translation>Éditer le &amp;jeu de carte</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation>&amp;Importer</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Exporter</translation>
    </message>
    <message>
        <source>Show &amp;toolbar</source>
        <translation>Afficher la barre d&apos;ou&amp;tils</translation>
    </message>
    <message>
        <source>Edit current card</source>
        <translation>Éditer la carte actuelle</translation>
    </message>
    <message>
        <source>&amp;Edit current card</source>
        <translation>É&amp;diter la carte actuelle</translation>
    </message>
    <message>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <source>Delete current card</source>
        <translation>Supprimer la carte actuelle</translation>
    </message>
    <message>
        <source>&amp;Delete current card</source>
        <translation>&amp;Supprimer la carte actuelle</translation>
    </message>
    <message>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <source>&amp;Clean duplicates</source>
        <translation>&amp;Gérer les cartes à doubles</translation>
    </message>
    <message>
        <source>&amp;Configure Mnemosyne</source>
        <translation>&amp;Configurer Mnemosyne</translation>
    </message>
    <message>
        <source>Getting started</source>
        <translation>Premiers pas</translation>
    </message>
    <message>
        <source>&amp;Getting started</source>
        <translation>&amp;Premiers pas</translation>
    </message>
    <message>
        <source>Down, Down</source>
        <translation>Down, Down</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Return</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Space</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>Show statistics</source>
        <translation>Afficher les statistiques</translation>
    </message>
    <message>
        <source>Show s&amp;tatistics</source>
        <translation>Afficher les s&amp;tatistiques</translation>
    </message>
    <message>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <source>Tip of the day</source>
        <translation>Astuce du jour</translation>
    </message>
    <message>
        <source>&amp;Tip of the day</source>
        <translation>&amp;Astuce du jour</translation>
    </message>
    <message>
        <source>Main toolbar (Mnemosyne)</source>
        <translation>Barre d&apos;outils principale (Mnemosyne)</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Fichier</translation>
    </message>
    <message>
        <source>&amp;Deck</source>
        <translation>&amp;Jeu de cartes</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
</context>
<context>
    <name>PreviewItemDlg</name>
    <message>
        <source>&lt;default&gt;</source>
        <translation>&lt;default&gt;</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Question :</translation>
    </message>
</context>
<context>
    <name>PreviewItemFrm</name>
    <message>
        <source>Preview card</source>
        <translation>Aperçu de la carte</translation>
    </message>
    <message>
        <source>Question:</source>
        <translation>Question :</translation>
    </message>
    <message>
        <source>Answer:</source>
        <translation>Réponse :</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Alt+O</source>
        <translation>Alt+O</translation>
    </message>
</context>
<context>
    <name>ProductTourFrm</name>
    <message>
        <source>Getting started</source>
        <translation>Premiers pas</translation>
    </message>
    <message>
        <source>Greetings!

I am Mnemosyne, a type of butterfly named after the Greek goddess of Memory. 

I can make it more efficient for you to memorise and remember answers to questions, by helping you focus on the cards you&apos;re most likely to forget and by not wasting your time on things you know well.

For that, I&apos;ll decide when to ask you the questions, and you&apos;ll need to rate how well you remember the answers.

Let&apos;s look at the meaning of these ratings now.</source>
        <translation>Salutations!

Je suis Mnémosyne, un genre de papillion qui tient son nom de la déesse grecque de la mémoire. 

Je peux vous aider à mémoriser et à garder en mémoire des réponses à des questions, en vous aidant à vous concentrer sur les cartes que vous avez tendance à oublier et à ne pas vous attarder sur ce que vous connaissez bien

Pour ce faire, je déciderais quand vous poser les questions et vous évaluerez à quel point vous vous souvenez des réponses.

Maintenant, jetons un coup d&apos;oeil à ces évaluations.</translation>
    </message>
    <message>
        <source>Introduction</source>
        <translation>Introduction</translation>
    </message>
    <message>
        <source>Grades range from 0 to 5.

Grades 0 and 1 are used if you don&apos;t know the answer yet, or if you have forgotten it. A card with grade 1 is starting to get more familiar than one with grade 0, and will be repeated less often.

I will keep on asking you these questions until you give them a grade 2 or higher (the exact grade doesn&apos;t matter). Grade 2 basically means that you think you&apos;ll be able to remember the card for at least one or two days. It signals the transition between short and long term memory.

I will schedule this card at some future date, when I think you&apos;ll still be able to remember it with some effort, without having forgotten it completely. This is the most efficient for the learning process.</source>
        <translation>les notes vont de 0 à 5.

Les notes 0 et 1 interviennent si vous ne connaissez pas encore la réponse ou si vous l&apos;avez oubliée. Une carte notée 1 commence à devenir plus familière qu&apos;une notée 0, et seront répétée moins souvent.

Je continuerai à vous poser ces questions jusqu&apos;à ce que vous leur donniez une note de 2 ou supérieure ( la note exacte n&apos;a pas d&apos;importance). La note 2 signifie que vous penser pouvoir vous rappelez de cette carte pendant au moins un jour ou deux. Cela marque le passage de la mémoire à court terme vers celle à long terme.

Je planifierai la révision de cette carte à une date ultérieure ou je  pense que vous pourrez encore vous en souvenir avec un peu d&apos;efforts, mais sans l&apos;avoir entièrement oubliée. C&apos;est ce qu&apos;il y a de plus éfficace pour apprendre.</translation>
    </message>
    <message>
        <source>Grades 0-2</source>
        <translation>Notes 0-2</translation>
    </message>
    <message>
        <source>If in the future I ask you the question too soon, and you&apos;re able to remember it without any effort, you rate the card a 5. I&apos;ll take this into account by waiting a lot longer before asking you this question again.

If I get it just right, so that you remember it, albeit with some effort, you use grade 4.

If on the other hand it takes you significant effort to remember the answer, and you think I&apos;ve waited too long to ask you this question, then rate the card 3.

If you fail to remember it altogether, rate it either 0 or 1, and I&apos;ll keep on asking you this question until you think you&apos;ll be able to remember it again for a few days.</source>
        <translation>Si par la suite je vous pose la question trop tôt, et que vous pouvez vous en souvenir sans le moindre effort, notez cette carte 5. Je prendrais cela en considération en attendant davantage avant de vous re-posez la question.

Si je vous ai posé la question le bon jour, de sorte que vous vous en êtes souvenu avec un peu d&apos;effort, mettez la note 4.

Si au contraire, il vous faut un grand effort pour vous rappelez de la réponse et que vous estimez que j&apos;ai trop attendu pour vous poser la question, notez alors la carte 3.

Si vous ne parvenez pas du tout à vous en souvenir, alors notez la soit 0, soit 1. Je continuerai alors à posez cette question jusqu&apos;à ce que vous pensez pouvoir vous en  souvenir pendant quelques jours.</translation>
    </message>
    <message>
        <source>Grades 3-5</source>
        <translation>Notes 3-5</translation>
    </message>
    <message>
        <source>If you&apos;re into statistics, I can keep detailed logs of your revisions.

Not only that, but if you want, I can upload transparently a completely anonymous version of these logs to a central site for analysis, so that you can help making me better. In this way, you also contribute to scientific research on long-term memory.

Uncheck the following box if you do not want to do this.</source>
        <translation>Si vous êtes avides de statistiques, je peux garder un journal détailé de vos révisions.

Je peux en plus, si vous le désirez, télécharger une version entièrement anonyme de ces journaux vers un site central pour analyse, vous m&apos;aiderez ainsi à m&apos;améliorer. Ce faisant, vous contribuez aussi à la recherche scientifique sur la mémoire à long terme.

Retirez le coche de la case suivante si vous ne voulez pas le faire.</translation>
    </message>
    <message>
        <source>Upload anonymous logs</source>
        <translation>Téléverser anonymement les journaux de bord</translation>
    </message>
    <message>
        <source>(You can always change this setting later using the &apos;Configure Mnemosyne&apos; menu option.)</source>
        <translation>(Vous pourrez toujours changer ce paramètre grâce à l&apos;option &quot;configurer Mnemosyne&quot; dans le menu)</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiques</translation>
    </message>
    <message>
        <source>Now you&apos;re ready to start!
&lt;p&gt;
Add new cards by clicking on the icon with the &apos;plus&apos; sign in the top left.
&lt;p&gt;
Remember, there is no need to worry about saving your work, I will do so automatically.
&lt;p&gt;
For best results, I suggest you do your revisions every day, although I&apos;ll try to cope as best I can if you postpone your revisions or if you want to learn ahead of time.
&lt;p&gt;
For more documentation, see http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Happy learning!</source>
        <translation>Vous êtes maintenant prêt à commencer!
&lt;p&gt;
Ajoutez de nouvelles cartes en cliquant sur l&apos;icône en forme de &quot;plus&quot; en haut à gauche.
&lt;p&gt;
Pas besoin de vous préoccupez de la sauvegarde de votre travail, Je le ferais automatiquement.
&lt;p&gt;
Pour les meilleurs résultats, je vous suggère de faire vos révisions tous les jours, bien que je ferais de mon mieux si vous repoussez vos révisions à plus tard, ou si vous voulez apprendre en avance.
&lt;p&gt;
Pour plus de documentation, référez vous à http://www.mnemosyne-proj.sourceforge.net.
&lt;p&gt;
Joyeux apprentissage!</translation>
    </message>
    <message>
        <source>Ready to start</source>
        <translation>Prêt à commencer</translation>
    </message>
</context>
<context>
    <name>QTextEdit2</name>
    <message>
        <source>Insert &amp;image</source>
        <translation>Insérer une &amp;image</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <source>Insert &amp;sound</source>
        <translation>Insérer un &amp;son</translation>
    </message>
    <message>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>&amp;3-sided input</source>
        <translation>Carte à &amp;3-faces</translation>
    </message>
    <message>
        <source>Image files</source>
        <translation>Fichiers image</translation>
    </message>
    <message>
        <source>Insert image</source>
        <translation>Insérer une image</translation>
    </message>
    <message>
        <source>Sound files</source>
        <translation>Fichiers son</translation>
    </message>
    <message>
        <source>Insert sound</source>
        <translation>Insérer un son</translation>
    </message>
</context>
<context>
    <name>StatisticsDlg</name>
    <message>
        <source>Scheduled cards for the next days:

</source>
        <translation>Cartes planifiées pour les jours suivants :

</translation>
    </message>
    <message>
        <source>In</source>
        <translation>Dans</translation>
    </message>
    <message>
        <source>day(s) :</source>
        <translation> jour(s) :</translation>
    </message>
    <message>
        <source>Number of cards with the following grades:

</source>
        <translation>Nombre de cartes avec les notes suivantes :

</translation>
    </message>
    <message>
        <source>Grade</source>
        <translation>Note</translation>
    </message>
    <message>
        <source>No current card.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Grade:</source>
        <translation type="unfinished">Note :</translation>
    </message>
    <message>
        <source>Easiness:</source>
        <translation type="unfinished">Facilité :</translation>
    </message>
    <message>
        <source>Repetitions:</source>
        <translation type="unfinished">Répétitions :</translation>
    </message>
    <message>
        <source>Lapses:</source>
        <translation type="unfinished">Oubils :</translation>
    </message>
    <message>
        <source>Days since last repetition:</source>
        <translation type="unfinished">Jours depuis la dernière répétition :</translation>
    </message>
    <message>
        <source>Days until next repetition:</source>
        <translation type="unfinished">Jours jusqu&apos;à la prochaine répétition :</translation>
    </message>
</context>
<context>
    <name>StatisticsFrm</name>
    <message>
        <source>Category</source>
        <translation>Catégorie</translation>
    </message>
    <message>
        <source>Cards</source>
        <translation>Cartes</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statistiques</translation>
    </message>
    <message>
        <source>Schedule</source>
        <translation>Planification</translation>
    </message>
    <message>
        <source>Grades</source>
        <translation>Notes</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Catégories</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>Current card</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TipDlg</name>
    <message>
        <source>For optimal results, it&apos;s best to do your repetitions every day.</source>
        <translation>Pour des résultats optimaux, il vaut mieux faire ses répétions chaque jour.</translation>
    </message>
    <message>
        <source>If you&apos;ve been away for a few days, don&apos;t worry about your backlog. Do as many cards as you feel like to catch up, the rest will be automatically rescheduled to the future.</source>
        <translation>Si vous vous êtes absenté quelques jours, ne vous faites pas de soucis pour votre retard accumulé. Pour le rattrapper, faites autant de cartes que votre humeur le dicte, le reste sera automatiquement replanifié pour une date ultérieure.</translation>
    </message>
    <message>
        <source>The &apos;number of grade 0 cards to learn at once&apos; setting determines how many new cards you are trying to learn at the same time. It does &lt;b&gt;not&lt;/b&gt; tell you how many new cards you need to learn per day. You are the judge of that: you can learn more cards or less cards, depending on how you feel.</source>
        <translation>Le paramètre &quot;nombres de cartes de note 0 à apprendre à la fois&quot; détermine combien de nouvelles cartes vous essayez d&apos;apprendre simultanément. Cela ne vous dit &lt;b&gt;pas&lt;/b&gt; combien de nouvelles cartes vous devez apprendre par jour. Vous êtes seule juge en la matière : vous pouvez apprendre plus de cartes ou moins de cartes, selon votre humeur de moment.</translation>
    </message>
    <message>
        <source>In summary, try to do your repetitions every day, but don&apos;t worry too much about getting the &apos;scheduled&apos; counter to zero, and certainly not about getting the &apos;Not memorised&apos; counter to zero.</source>
        <translation>Pour résumer, essayer de faire vos répétitions chaque jour, mais ne vous soucier pas trop de ramener à zéro le compteur &quot;cartes planifiés&quot;, et en aucun cas de ramener le compteur &quot;non-mémorisés&quot; à zéro.</translation>
    </message>
    <message>
        <source>Grade 1 cards are different from grade 0 cards in the sense that they show up less often and are not subject to the &apos;number of grade 0 cards to learn at once&apos; setting.</source>
        <translation>Les cartes notées 1 sont différentes des cartes notées 0, dans la mesure ou elles apparaissent moins souvent et ne sont pas soumises au paramètre &quot;Nombres de cartes de note 0 à apprendre à la fois&quot;.</translation>
    </message>
    <message>
        <source>You can use keyboard shortcuts to do your repetitions. Enter, Return or Space stand for the default action (&apos;Show answer&apos; or &apos;grade 4&apos;). The number keys can be used for grading.</source>
        <translation>Vous pouvez utiliser des raccourcis clavier pour faire vos répétitions. Entrée, Retour ou Espace pour l&apos;action par défaut (&quot;afficher la réponse&quot;). On peut utiliser les touches numériques pour noter.</translation>
    </message>
    <message>
        <source>You can select the categories you wish to study in the &apos;Activate categories&apos; menu option.</source>
        <translation>Vous pouvez choisir les catégories à réviser via l&apos;option &quot;Activer les catégories&quot;.</translation>
    </message>
    <message>
        <source>It is recommended to put all your cards in a single database and use categories to organise them. Using &apos;Activate categories&apos; is much more convenient than have to load and unload several databases.</source>
        <translation>Il est recommendé de mettre toutes vos cartes dans une seule base de données et d&apos;utiliser des catégories pour les organiser. Se servir de &quot;&apos;Activer les catégories&quot; est bien plus commode que de devoir charger et décharger plusieurs bases de données.</translation>
    </message>
    <message>
        <source>You can import cards in a wide variety of formats: tab delimited txt files, Supermemo files, ... .</source>
        <translation>Vous pouvez importer des cartes dans une grande variété de formats : fichiers txt délimité par une tabulation, fichiers Supermemo, ... .</translation>
    </message>
    <message>
        <source>If you have cards in Word or Excel, export them to tab delimited txt files with UTF-8 unicode encoding to be able to import them into Mnemosyne.</source>
        <translation>Si vous avez de cartes dans Word ou dans Excel, exporter les en tant que &quot; fichier txt délimité par une tabulation&quot; avec l&apos;encodage &quot;UTF-8 unicode&quot;  pour pouvoir les importer dans Mnemosyne.</translation>
    </message>
    <message>
        <source>If you want to print out your cards, export them to a txt file which you can then print from your favourite Word processor.</source>
        <translation>Si vous désirez imprimer vos cartes, exportez les vers un fichier txt que vous pourrez ensuite imprimer via votre logiciel de traitement de texte préféré.</translation>
    </message>
    <message>
        <source>You can share your cards with someone else by exporting them to XML and choosing the &apos;Reset learning data&apos; option on export.</source>
        <translation>Vous pouvez partagez vos cartes avec autrui en les exportant au format XML et en choisissant l&apos;option &quot;Ré-initialiser les données d&apos;apprentissage lors de l&apos;export&quot;.</translation>
    </message>
    <message>
        <source>If you study a foreign language with a different script, the default font size is sometimes a bit small. If you want to increase the size of these characters but keep the size of English text, use the &apos;increase size of non-latin characters by X points&apos; option.</source>
        <translation>Si vous étudier une langue étrangère avec un scripte différent, la taille de police par défaut est parfois un peu petite. Si vous désirez agrandire la taille de ces caractères sans changer celle de l&apos;alphabet latin, utilisez l&apos;option &quot;Agrandir les caractères non-latin de X point&quot;.</translation>
    </message>
    <message>
        <source>You can add images and sounds to your cards. Right-click on the question or answer field when editing a card to bring up a pop-up menu to do so.</source>
        <translation>Vous pouvez ajouter des images et des sons à vos cartes. Quand vous éditer une carte, faites un clic droit dans la partie question ou réponse pour faire apparaître un menu contextuel.</translation>
    </message>
    <message>
        <source>It is recommended to keep your sound and image files inside your .mnemosyne directory. That way, it&apos;s easier to transfer your data between different computers.</source>
        <translation>Il est recommandé de garder vos fichiers de sons et d&apos;images à l&apos;intérieur du répértoire .mnemosyne. Il vous sera ainsi plus facile de transférer vos données d&apos;un ordinateur à l&apos;autre.</translation>
    </message>
    <message>
        <source>When adding a three-sided card, two regular cards will be created. One with as question the written form and as answer the pronunciation and the translation, and one with as question the translation and as answer the written form and the pronunciation.</source>
        <translation>À l&apos;ajout d&apos;une carte à trois faces, deux cartes standard seront créées. L&apos;une aura pour question la forme écrite et pour réponse la prononciation et la traduction. L&apos;autre aura pour question la traduction et pour la réponse la forme écrite et sa prononciation.</translation>
    </message>
    <message>
        <source>You can use basic HTML tags in your cards to control their appearance.</source>
        <translation>Vous pouvez vous servir de balises HTML élémentaires dans vos cartes pour contrôler leur apparence.</translation>
    </message>
    <message>
        <source>Mnemosyne can use LaTeX to render mathematical formulas, e.g. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (For this, you need LaTeX and dvipng installed.)</source>
        <translation>XXXXXXXXXXXXX
Mnemosyne peut utiliser LaTeX pour exprimer des formules mathématiques, i.e. &lt;$&gt;x^2+y^2=z^2&lt;/$&gt;. (Dans ce cas, LaTeX et dvipng doivent être installés.)</translation>
    </message>
    <message>
        <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
        <translation>La meilleure façon de sauvegarder vos données est de copier votre répertoire .mnemosyne (si vous suivez la procédure recommandée d&apos;y garder tous vos fichiers...) et le placer sur un disque différent. Mnemosyne  génère automatiquement des sauvegardes en format XML sous ./mnemosyne/backups,  mais ça ne sera pas d&apos;un grand secours si ce disque-là meurt... </translation>
    </message>
    <message>
        <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
        <translation>Vous pouvez lancer Mnemosyne depuis une clé USB. Copiez C:\Program Files\Mnemosyne dans votre clé USB, puis copiez le répertoire .mnemosyne de votre répértoire personnel dans le répertoire Mnemosyne de votre clé USB.</translation>
    </message>
    <message>
        <source>If you use Mnemosyne on multiple computers, there is a handy tool called Unison to help you synchronise your data. See the Mnemosyne website for more information.</source>
        <translation>Si vous utilisez Mnemosyne sur plusieurs ordinateurs, il y a un outil bien pratique nommée Unison qui vous aidera à synchroniser vos données. Référez vous au Site web de Mnemosyne pour de plus amples renseignements.</translation>
    </message>
    <message>
        <source>You can sort the cards in the &apos;Edit Deck&apos; dialog by answer or by category by clicking on the corresponding column title. Clicking again changes the sort order.</source>
        <translation>Dans le dialogue &quot;éditer le jeu de cartes&quot;, vous pouvez trier les cartes par réponse ou par catégorie en cliquant sur le titre de la colonne correspondante. Un deuxième clic changera l&apos;ordre du tri.</translation>
    </message>
    <message>
        <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
        <translation>Si vous désirez un contrôle plus fin sur le comportement de LaTeX, voyez les explications concernant les balises &lt;$$&gt;...&lt;/$$&gt; et &lt;latex&gt;...&lt;/latex&gt; sur le site de Mnemosyne.</translation>
    </message>
    <message>
        <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
        <translation>Les utilisateurs avancés peuvent davantage personnaliser Mnemosyne en éditant le fichier config.py dans leur répertoire .mnemosyne. Ils peuvent aussi installer des plugins pour personnaliser encore plus Mnemosyne.</translation>
    </message>
</context>
<context>
    <name>TipFrm</name>
    <message>
        <source>Tip of the day</source>
        <translation>Astuce du jour</translation>
    </message>
    <message>
        <source>&lt;b&gt;Did you know...?&lt;/b&gt;</source>
        <translation>&lt;b&gt;Saviez vous...?&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&amp;Show tips on startup</source>
        <translation>&amp;Afficher les astuces au démarrage</translation>
    </message>
    <message>
        <source>Alt+S</source>
        <translation>Alt+S</translation>
    </message>
    <message>
        <source>&amp;Previous</source>
        <translation>&amp;Précédent</translation>
    </message>
    <message>
        <source>Alt+P</source>
        <translation>Alt+P</translation>
    </message>
    <message>
        <source>&amp;Next</source>
        <translation>&amp;Suivant</translation>
    </message>
    <message>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fermer</translation>
    </message>
    <message>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
</context>
</TS>
